Learn R Programming

tktdjl2r (version 0.2.0)

runMFx: Function to compute the optimal multiplication factor for SD model with binary search using distribution of parameters

Description

Function to compute the optimal multiplication factor for SD model with binary search using distribution of parameters

Usage

runMFx(
  time,
  conc,
  model = NULL,
  parms,
  X = 50,
  time_MFx,
  MFx_range = c(0, 1000),
  accuracy = 0.01,
  threshold_iter = 100,
  quiet = FALSE
)

Arguments

time

vector of time

conc

vector of concentration

model

model type SD or IT

parms

list of parameters

X

percentage of reduction of survival

time_MFx

time at which Mulitplication Factor has to be evaluated

MFx_range

range of Multiplication factor to investigate

accuracy

accuracy for the binary search algorithm

threshold_iter

maximum number of iteration

quiet

If TRUE, remove log information