Function to compute the optimal multiplication factor for SD model with binary search using distribution of parameters
runMFx(
time,
conc,
model = NULL,
parms,
X = 50,
time_MFx,
MFx_range = c(0, 1000),
accuracy = 0.01,
threshold_iter = 100,
quiet = FALSE
)vector of time
vector of concentration
model type SD or IT
list of parameters
percentage of reduction of survival
time at which Mulitplication Factor has to be evaluated
range of Multiplication factor to investigate
accuracy for the binary search algorithm
maximum number of iteration
If TRUE, remove log information